
-module(connections_sup).

-behaviour(supervisor).

%% API
-export([start_link/1, start_link/2]).

%% Supervisor callbacks
-export([init/1]).

%% Helper macro for declaring children of supervisor
-define(CHILD(I, Type, Args), {I, {I, start_link, Args}, permanent, 5000, Type, [I]}).

-define(SERVER, ?MODULE). 

%% ===================================================================
%% API functions
%% ===================================================================

start_link(Urls) ->
    supervisor:start_link({local, ?MODULE}, ?MODULE, [Urls, 1]).

start_link(Urls, Factor) ->
    supervisor:start_link({local, ?MODULE}, ?MODULE, [Urls, Factor]).

%% ===================================================================
%% Supervisor callbacks
%% ===================================================================

init([Urls, Factor]) ->
    {ok, { 
       {one_for_one, 0, 1}, 
       [?CHILD(connections, worker, [Urls, Factor])]} }.
