%%%-------------------------------------------------------------------
%%% @author Konstantin Kalin <kkalin@kkalin-macbook>
%%% @copyright (C) 2012, Konstantin Kalin
%%% @doc
%%%
%%% @end
%%% Created : 20 Apr 2012 by Konstantin Kalin <kkalin@kkalin-macbook>
%%%-------------------------------------------------------------------
-module(consumer).

-export([start/1, start/2, start_consumers/4, start_consumer/2]).

%%%===================================================================
%%% API
%%%===================================================================

%%--------------------------------------------------------------------
%% @doc
%% Starts Consumer application and creates AMQP connection for each Urls
%% @end
%%--------------------------------------------------------------------
start(Urls) ->
    application:start(sasl),
    application:start(consumer),
    init_connections(Urls, 1).

%%--------------------------------------------------------------------
%% @doc
%% Starts Consumer application and creates AMQP connections for each Urls
%% Factor is AMQP connections amount per Url
%% @end
%%--------------------------------------------------------------------
start(Urls, Factor) ->
    application:start(sasl),
    application:start(consumer),
    init_connections(Urls, Factor).

%%--------------------------------------------------------------------
%% @doc
%% Starts and subsribes one consumer to given Exchange
%% @end
%%--------------------------------------------------------------------
start_consumer(Exchange, Type) ->
    Connection = connections:get_connection(),
    consumer_sup:start_consumer(Connection, Exchange, Type, <<"key.1">>).

%%--------------------------------------------------------------------
%% @doc
%% Starts and subscribe consumers to given Exchange
%% Count is Consumers amount;
%% Index is a start index to construct a routing key.
%% @end
%%--------------------------------------------------------------------
start_consumers(_Exchange, _Type, 0, _Index) ->
    ok;
start_consumers(Exchange, Type, Count, Index) ->
    Key = << <<"key.">>/binary, (list_to_binary(integer_to_list(Count + Index)))/binary >>,
    Connection = connections:get_connection(),
    consumer_sup:start_consumer(Connection, Exchange, Type, Key),
    start_consumers(Exchange, Type, (Count - 1), Index).

init_connections(Urls, Factor) ->
    connections_sup:start_link(Urls, Factor).
