%%%-------------------------------------------------------------------
%%% @author Konstantin Kalin <kkalin@kkalin-macbook.local>
%%% @copyright (C) 2012, Konstantin Kalin
%%% @doc
%%%
%%% @end
%%% Created : 23 Apr 2012 by Konstantin Kalin <kkalin@kkalin-macbook.local>
%%%-------------------------------------------------------------------
-module(publisher).

-export([start/1, start/2, start_publish/6, start_publish/4]).

%%--------------------------------------------------------------------
%% @doc
%% Starts Publisher application and creates AMQP connection to given Urls
%% @end
%%--------------------------------------------------------------------
start(Urls) ->
    application:start(sasl),
    application:start(publisher),
    init_connections(Urls, 1).

%%--------------------------------------------------------------------
%% @doc
%% Starts Publisher application and creates AMQP connections for each Urls
%% Factor is AMQP connections amount per Url
%% @end
%%--------------------------------------------------------------------
start(Urls, Factor) ->
    application:start(sasl),
    application:start(publisher),
    init_connections(Urls, Factor).

%%--------------------------------------------------------------------
%% @doc
%% Start one publisher and publish messages with rate
%%       Amount is messages amount to be sent
%%       Rate is rate messages per second
%% @end
%%--------------------------------------------------------------------
start_publish(Exchange, Type, Amount, Rate) ->
    Connection = connections:get_connection(),
    publisher_sup:start_publish(Connection, Exchange, Type, <<"key.1">>, Amount, Rate).

%%--------------------------------------------------------------------
%% @doc
%% Start publishers and publish messages with rate
%%       Amount is messages amount to be sent
%%       Rate is messages rate per second
%%       Count is publishers amount to be created
%%       Index is starting index to create routing keys. 
%% @end
%%--------------------------------------------------------------------
start_publish(_Exchange, _Type, _Count, _Rate, 0, _Index) ->
    ok;
start_publish(Exchange, Type, Amount, Rate, Count, Index) ->
    Key = << <<"key.">>/binary, (list_to_binary(integer_to_list(Count + Index)))/binary >>,
    Connection = connections:get_connection(), 
    publisher_sup:start_publish(Connection, Exchange, Type, Key, Amount, Rate),
    start_publish(Exchange, Type, Amount, Rate, (Count - 1), Index).

init_connections(Urls, Factor) ->
    connections_sup:start_link(Urls, Factor).
